==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/account/verify.php <==
<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: verify.php,v 1.13 2004/11/22 08:25:48 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";    

####### function login_valid()
####### checks for valid login from form post

function verify_login_valid()	
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':verify_login_valid()	';	global $HTTP_POST_VARS;

	if (!$GLOBALS['form_loginname']) return 0;

	# first check just confirmation hash
	$res = db_query('SELECT confirm_hash,status FROM user WHERE '
		.'user_name=\''.$GLOBALS['form_loginname'].'\'');

	if (db_numrows($res) < 1) {
		$GLOBALS['error_msg'] = _("Invalid username.");
		return 0;
	}
	$usr = db_fetch_array($res);

	if (strcmp($GLOBALS['confirm_hash'],$usr['confirm_hash'])) {
		$GLOBALS['error_msg'] = _("Invalid confirmation hash.");
		return 0;
	}

	# then check valid login	
	return (session_login_valid($GLOBALS['form_loginname'],$GLOBALS['form_pw'],1));
}

####### first check for valid login, if so, redirect

if ($update){
	$success=verify_login_valid();
	if ($success) {
		$res = db_query("UPDATE user SET status='A' WHERE user_name='$GLOBALS[form_loginname]'");
		session_redirect($GLOBALS['sys_home']."account/first.php");
	}
}

site_header(array('title'=>_("Login")));

print '<h3> '.sprintf(_("%s Account Verification"),$GLOBALS['sys_name']).'</h3>';
print '<p>'._("In order to complete your registration, login now. Your account will then be activated for normal logins").'.</p>';


print form_header($PHP_SELF, $form_id);

print '<p><span class="preinput">'._("Login Name").':</span><br />&nbsp;&nbsp;';
print form_input("text", "form_loginname");
print '</p>';

print '<p><span class="preinput">'._("Password").':</span><br />&nbsp;&nbsp;';
print form_input("password", "form_pw");
print '</p>';

print form_input("hidden", "confirm_hash", $confirm_hash);
print form_footer(_("Login"));

site_footer(array());

?>

==> savane-1.0.8+2.tar.gz: savane-1.0.8+2/frontend/php/account/verify.php <==
<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: verify.php,v 1.14 2005/06/30 17:19:33 toddy Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


require "../include/pre.php";    

####### function login_valid()
####### checks for valid login from form post

function verify_login_valid()	
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':verify_login_valid()	';	global $HTTP_POST_VARS;

	if (!$GLOBALS['form_loginname']) return 0;

	# first check just confirmation hash
	$res = db_query('SELECT confirm_hash,status FROM user WHERE '
		.'user_name=\''.$GLOBALS['form_loginname'].'\'');

	if (db_numrows($res) < 1) {
		$GLOBALS['error_msg'] = _("Invalid username.");
		return 0;
	}
	$usr = db_fetch_array($res);

	if (strcmp($GLOBALS['confirm_hash'],$usr['confirm_hash'])) {
		$GLOBALS['error_msg'] = _("Invalid confirmation hash.");
		return 0;
	}

	# then check valid login	
	return (session_login_valid($GLOBALS['form_loginname'],$GLOBALS['form_pw'],1));
}

####### first check for valid login, if so, redirect

if ($update){
	$success=verify_login_valid();
	if ($success) {
		$res = db_query("UPDATE user SET status='A' WHERE user_name='$GLOBALS[form_loginname]'");
		session_redirect($GLOBALS['sys_home']."account/first.php");
	}
}

site_header(array('title'=>_("Login")));

print '<h3> '.sprintf(_("%s Account Verification"),$GLOBALS['sys_name']).'</h3>';
print '<p>'._("In order to complete your registration, login now. Your account will then be activated for normal logins").'.</p>';


print form_header($PHP_SELF, $form_id);

print '<p><span class="preinput">'._("Login Name").':</span><br />&nbsp;&nbsp;';
print form_input("text", "form_loginname");
print '</p>';

print '<p><span class="preinput">'._("Password").':</span><br />&nbsp;&nbsp;';
print form_input("password", "form_pw");
print '</p>';

print form_input("hidden", "confirm_hash", $confirm_hash);
print form_footer(_("Login"));

site_footer(array());

?>
